
/*
 
 This is the "main" entry point of our application. There IS a source file called
 "main" but it is very rare that you will ever need to modify that file.
 
 Every ios application has an App Delegate. The app delegate is a singleton (only
 instantiated once) that is used as a middle-man between your code and the the 
 operating system. 
 
 What makes an app delegate is not inheritance but rather adhering to a particular
 interface. In objective-C, "interface" are called "protocols". Below, we see that
 the "iphone_devAppDelegate" class inherits from "NSObject" and claims to adhere to 
 the "UIApplicationDelegate" protocol. Because it adheres to this protocol is MUST
 implement at least the following method:
 
 application:didFinishLaunchingWithOptions:
 
 This is called when the actual application is launched and your code is ready to 
 take over (ie. things should now be drawn on the screen).
 
*/

// Include some really important UI stuff...
#import <UIKit/UIKit.h>

// The "iphone_devAppDelegate" interface: data members and methods.
@interface iphone_devAppDelegate : NSObject <UIApplicationDelegate> {
    
    UIWindow *window;
    UINavigationController *navigationController;
}

// Properties are a nice feature of objective-C that automatically create
// a "getter" and "setter" method for you. Thus, if you change the underlying
// data structure of a certain data member, it won't break client code.
//
// "nonatomic" simply means don't worry about making this variable threadsafe and
// "retain" has to do with memory management.
@property (nonatomic, retain) IBOutlet UIWindow *window;
@property (nonatomic, retain) IBOutlet UINavigationController *navigationController;

@end

